#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14.0
%define plugin clipman
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.6.4
Release:        bp155.2.3.1
Summary:        Clipboard Manager Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-clipman-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.6/%{name}-%{version}.tar.bz2
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.22.29
BuildRequires:  pkgconfig(gio-2.0) >= 2.60.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.60.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.29
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.14.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.14.0
BuildRequires:  pkgconfig(xproto) >= 7.0.0
BuildRequires:  pkgconfig(xtst) >= 1.0.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Obsoletes:      xfce4-panel-plugin-clipman-doc < 1.2.4
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo
Requires:       xfce4-panel >= %{panel_version}
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-doc = %{version}
Recommends:     %{name}-lang = %{version}

%description
This is a clipboard manager which comes with a plugin for the Xfce Panel. It
stores the X selection (primary and clipboard) contents even after an
application has quit and is able to handle text and image data. Furthermore, it
can be configured to execute arbitrary actions when the selection content
matches specific regular expressions.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libclipman.la
rm -f %{buildroot}%{_libdir}/debug/usr/bin/%{name}-%{version}-0.x86_64.debug

%suse_update_desktop_file xfce4-clipman
%suse_update_desktop_file %{name}-autostart

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_datadir}/xfce4/panel/plugins/xfce4-clipman-plugin.desktop
%{_sysconfdir}/xdg/autostart/xfce4-clipman-plugin-autostart.desktop
%config %{_sysconfdir}/xdg/xfce4/panel/xfce4-clipman-actions.xml
%dir %{_sysconfdir}/xdg/xfce4/panel
%{_libdir}/xfce4/panel/plugins/libclipman.so
%{_bindir}/xfce4-clipman
%{_bindir}/xfce4-clipman-history
%{_bindir}/xfce4-clipman-settings
%{_bindir}/xfce4-popup-clipman
%{_bindir}/xfce4-popup-clipman-actions
%{_datadir}/applications/xfce4-clipman.desktop
%{_datadir}/applications/xfce4-clipman-settings.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/xfce4-clipman.appdata.xml
%{_datadir}/icons/hicolor/*/apps/*

%files lang -f %{name}.lang

%changelog
* Tue Aug 15 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 1.6.4
  * history-dialog: Fix memory leak
  * history-dialog: Keep paste-on-activate in sync with the settings
  * history-dialog: Remove useless creation/destruction of menu
  * Simplify main app creation
  * history-dialog: Better fit with the way GApplication works
  * settings: Remove wrong signal handler
  * settings: Better fit with the way GApplication works
  * popup-clipman: Enable translations
  * popup-clipman: Properly use GApplication
  * Move default clipboard restoration from manager to collector
  * gsd-clipboard: Add missing sanity check
  * Remove dead code
  * menu: Add some icons
  * history: Clear history when it's disabled
  * menu: Shift entries in reverse order
  * Revert "Enable reverse-order option"
  * menu: Improve management of clear history entries
  * menu: Improve management of primary clipboard entry
  * history: Refactor item_to_restore into image_to_restore
  * settings: Align paste-on-activate combo like other widgets
  * collector: Properly sync primary clipboard when default is empty
  * collector: Fix primary timeout management
  * collector: Remove unused function
  * Make 'add-primary-clipboard' management internal to the collector
  * Make 'add-primary-clipboard' imply 'persistent-primary-clipboard'
  * settings: Fix 'skip-action-on-key-down' sync and improve strings
  * collector: Make actions work again for selections
  * collector: Fix memory leak
  * collector: Properly disconnect signal handlers
  * gsd-clipboard: Properly reset source id
  * menu: Fix crash when selecting QR code
  * Remove XfcePluggable from settings desktop file
  * build: tests: Fix compiler warnings
  * Translation Updates
* Tue Mar 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.6.3
  * Update copyright year and bug report address
  * history: Fix inactive copy button (Fixes #54)
  * Shorten the selection text in menu
  * Move text shorten code to common function
  * build: Fix autotools warnings
  * Allow to clear history when only selection is visible
  * Fix blurry images in plugin menu when UI scale > 1
  * Fix link in README
  * Remove ENABLE_NLS ifdefs
  * Update `.gitignore`
  * Add primary clipboard persistence
  * [PATCH] build: Fix intltool lock file problem during make distcheck
  * Fix text preview
  * Replace `g_malloc0()` with safer alternative `g_new0()`
  * Use `filename` before freeing it
  * Fix invalid "Show full history..." menu item behavior (#29)
  * Fix GLib macro expansion compiler warnings
  * Update copyright year
  * Check if already running before adding as panel plugin
  * Do not try to register application twice
  * Correctly handle a timeout source life cycle within a function
  * Fix Gtk-CRITICAL when showing main menu
  * Require glib 2.60
  * Translation Updates
* Mon May  3 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.2
  * Add G_GNUC_FALLTHROUGH definition if GLib < 2.60
  * Remove obsolete GTK_CHECK_VERSION checks
  * Fix function prototypes
  * Remove GSourceFunc casts
  * Fix compilation warnings
  * automake: Enable subdir-objects
  * autoconf: Some updates
  * Check for `locale.h` required in release mode
  * Update `.gitignore`
  * Require gtk 3.22.29
  * Fix GCC warnings
  * Fix return type of grab_keyboard
  * Add README.md
  * Avoid deprecated warnings with Gdk >= 3.22
  * Add basic GitLab pipeline
  * bxo#16717: Move from exo-csource to xdt-csource
  * Make settings window title translateable (bxo#16625)
  * history: Re-enable singleton
  * menu: Indicate primary and clipboard content
  * menu: Indicate the primary clipboard item
  * Speed up shutdown and paste
  * Correct location of appstream info
  * Fix a couple of grammatical errors
  * Translation Updates
- Drop xfce4-clipman-plugin-1.4.2-fix-nonvoid-function.diff,
  fixed upstream
* Sun Apr  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.1
  * Add translateable files to POTFILES (bxo#16608)
  * Bump libxfce4ui ifdef to 4.15.1
  * Translation Updates
* Sun Mar 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.0
  * Add standalone dialog to search history: xfce4-clipman-history
  * Don't delete the history on startup
  * plugin: Indicate if clipman is disabled (bxo#11381)
  * plugin: Bind middle-click to toggle "inhibit"
  * plugin: Add "Clipman settings..." menuitem
  * plugin: "Show full history..." menuitem
  * plugin: Wire up max-menu-items setting
  * settings: Make strings translatablei (bxo#16496)
  * settings: Improve responsiveness of actions tab
  * settings: Replace GtkStock icons and tweak actions dialog
  * settings: Revamp UI and add max-menu-items setting
  * settings: Further UI tweaks
  * daemon: Show info dialog if already running
  * Add warning if clipman is not running
  * Show info/warning dialogs if clipman is (not) running
  * Add clipman-settings desktop file
  * Replace deprecated g_type_class_add_private
  * Replace GtkStock items
  * Improve clipman autostart file
  * Update copyright
  * Update gitignore
  * Translation Updates
* Mon Mar  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.4
  * settings: Improve layout
  * settings: Drop some GtkStock items
  * Update support URLs from goodies to docs.xfce.org (bxo#16141)
  * Drop deprecated Gtk style properties
  * Also show desktop file in Cinnamon (bxo#14058)
  * Fix getting modifier in gsd-clipboard-manager (bxo#14642), obsoletes
    xfce4-clipman-plugin-1.4.3-fix-gdk_window_get_device_position.diff
  * Fix typo
  * Translation Updates
* Fri Feb 28 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add xfce4-clipman-plugin-1.4.3-fix-gdk_window_get_device_position.diff
  to fix error stream in .xsession-errors file (boo#1165231)
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Jul 29 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
* Wed Jan  2 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 1.4.3 (2018-10-27):
  - Switch to xfce_panel_plugin_get_icon_size for consistent icon sizes
  - Make sure the "Disable" menuitem is shown in the panel plugin
  - Translation updates
* Fri Jul 21 2017 seife+obs@b1-systems.com
- update to version 1.4.2
  - Port to GtkApplication (should help with keyboard shortcut issues)
  - Translation updates
- add xfce4-clipman-plugin-1.4.2-fix-nonvoid-function.diff to fix build
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 1.4.1
  - new application icon
  - various icon and menu geometry fixes
  - translation updates
- do not package ChangeLog file, NEWS is enough
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 1.4.0
  - port to Gtk3 / GtkApplication
* Sat May 31 2014 gber@opensuse.org
- update to version 1.2.6
  - Include an .appdata.xml file
  - Switch to gtk_clipboard_request_text for retrieving text
  - Position menu with XfceScreenPosition
  - Update default action Long URL with whitespace \s
  - Fix link to online documentaion
* Wed Feb  5 2014 gber@opensuse.org
- updated to version 1.2.5
  - Bind skip-action option on the correct radio button (setting
    was reversed)
  - Set empty text on the clipboard when clearing history
* Sun Feb  2 2014 gber@opensuse.org
- updated to version 1.2.4
  - Removed doc submodule
  - Define different menmonic
  - QR-code encoder
  - Move Disable item inside context/right-click menu
  - Allow skipping actions by pressing or not CTRL
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Tue Apr 17 2012 gber@opensuse.org
- fix source URL
* Tue Apr 10 2012 gber@opensuse.org
- update to version 1.2.3
  - use new online documentation location http://docs.xfce.org/
  - handle images and texts as one stack
  - added a checkbox "Don't ask again" to clear the history
  - include rows support from Xfce Panel 4.9
  - don't terminate gtk_message_dialog_new_with_markup with
    NULL
  - use g_return_val_if_fail instead of g_return_if_fail
- dropped obsolete
  xfce4-clipman-plugin-1.2.2-fix-gtk_message_dialog_new_with_markup-usage.patch,
  xfce4-clipman-plugin-1.2.2-fix-non-void-function-not-returning-value.patch
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Mon Feb 20 2012 gber@opensuse.org
- add missing build dependencies
* Thu Feb 16 2012 gber@opensuse.org
- revert
  xfce4-panel-plugin-clipman-fix-installation-locations.patch
  %%{_datadir}/xfce4/panel/plugins and
  %%{_libdir}/xfce4/panelr/-plugins are preferred by upstream
* Mon Feb 13 2012 gber@opensuse.org
- added xfce4-panel-plugin-clipman-fix-installation-locations.patch
  in order to install the plugin executable into
  %%{_libdir}/xfce4/panel-plugins and the desktop file into
  %%{_datadir}/xfce4/panel-plugins to be consistent with all other
  plugins
* Mon Jan  9 2012 gber@opensuse.org
- remove hardcoded version dependency of
  xfce4-panel-plugin-clipman-doc on xfce4-panel-plugin-clipman
* Sun Nov 13 2011 gber@opensuse.org
- update to version 1.2.2
  - new options in the settings dialog under the tab "Tweaks":
  - reorder-items: push or not the last copied text to the top of
    history, default is set to true
  - skip-action-on-key-down: ignore matched actions when Ctrl is
    pressed down at the end of the selection, default is set to
    false
  - include existing hidden options in the "Tweaks" tab
  - use new Xfce Panel plugin installation location
- added
  xfce4-clipman-plugin-1.2.2-fix-non-void-function-not-returning-value.patch
  which fixes a non-void function not returning a value (bxo#8106)
- added
  xfce4-clipman-plugin-1.2.2-fix-gtk_message_dialog_new_with_markup-usage.patch
  which fixes the usage of gtk_message_dialog_new_with_markup
  (bxo#8147)
- dropped obsolete
  xfce4-panel-plugin-clipman-1.1.3-use-docdir.patch,
  xfce4-panel-plugin-clipman-1.1.3-fix-exo-version.patch,
  xfce4-panel-plugin-clipman-1.1.3-fix-missing-return-value.patch,
  xfce4-panel-plugin-clipman-1.1.3-catch-null-value.patch,
  xfce4-panel-plugin-clipman-1.1.3-fix-memory-leak.patch
* Fri Oct 21 2011 gber@opensuse.org
- added xfce4-panel-plugin-clipman-1.1.3-use-docdir.patch in order
  to use docdir correctly
- install HTML documentation under
  /usr/share/xfce4/xfce4-clipman-plugin/html
- package AUTHORS ChangeLog COPYING NEWS README TODO
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
